@@ -3,8 +3,6 @@
 #' Finds and imports reflectance/transmittance/absorbance data from spectra
 #' files in a given location.
 #'
-#' @inheritParams lr_parse_generic
-#'
 #' @param where Folder in which files are located (defaults to current working
 #' directory).
 #' @param ext File extension to be searched for, without the "." (defaults to
@@ -21,6 +19,7 @@
 #' @param interpolate Boolean indicated whether spectral data should be
 #' interpolated and pruned at every nanometre. Note that this option can only
 #' work if all input data samples the same wavelengths. Defaults to `TRUE`.
+#' @param ... Arguments passed to individual parsers.
 #'
 #' @details
 #' You can customise the type of parallel processing used by this function with
@@ -45,16 +44,24 @@
 #' spcs <- lr_get_spec(system.file("testdata", package = "lightr"), ext = "jdx")
 #' head(spcs)
 #'
-lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
-                        decimal = ".", sep = NULL, subdir = FALSE,
-                        subdir.names = FALSE, ignore.case = TRUE,
-                        interpolate = TRUE) {
-
+lr_get_spec <- function(
+  where = getwd(),
+  ext = "txt",
+  lim = c(300, 700),
+  subdir = FALSE,
+  subdir.names = FALSE,
+  ignore.case = TRUE,
+  interpolate = TRUE,
+  ...
+) {
   extension <- paste0("\\.", ext, "$", collapse = "|")
 
-  file_names <- list.files(where,
-    pattern = extension, ignore.case = ignore.case,
-    recursive = subdir, include.dirs = subdir
+  file_names <- list.files(
+    where,
+    pattern = extension,
+    ignore.case = ignore.case,
+    recursive = subdir,
+    include.dirs = subdir
   )
 
   # This step is needed to ensure reproducibility between locales and platforms
@@ -63,8 +70,10 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
   nb_files <- length(file_names)
 
   if (nb_files == 0) {
-    warning('No files found. Try a different value for argument "ext".',
-            call. = FALSE)
+    warning(
+      'No files found. Try a different value for argument "ext".',
+      call. = FALSE
+    )
     return(NULL)
   }
 
@@ -81,8 +90,8 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
   message(nb_files, " files found; importing spectra:")
 
   if (interpolate) {
-    gsp <- function(f) {
-      df <- dispatch_parser(f, decimal = decimal, sep = sep)[[1]]
+    gsp <- function(f, ...) {
+      df <- dispatch_parser(f, ...)[[1]]
 
       # Trim now because otherwise, approx() can fill the region of interest
       # with bogus data (e.g., if the data is complete between 200-300nm and
@@ -90,18 +99,20 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
       bounds <- which(df$wl >= lim[1] & df$wl <= lim[2])
 
       if (length(bounds) == 0) {
-        warning(f, " does not contain spectral data over the provided wl range",
-                call. = FALSE)
+        warning(
+          f,
+          " does not contain spectral data over the provided wl range",
+          call. = FALSE
+        )
         return(NULL)
       }
       df <- df[c(min(bounds) - 1, bounds, max(bounds) + 1), ]
 
-      approx(df[, "wl"], df[, "processed"],
-             xout = range, ties = "ordered")$y
+      approx(df[, "wl"], df[, "processed"], xout = range, ties = "ordered")$y
     }
   } else {
-    gsp <- function(f) {
-      dispatch_parser(f, decimal = decimal, sep = sep)[[1]]
+    gsp <- function(f, ...) {
+      dispatch_parser(f, ...)[[1]]
     }
   }
 
@@ -110,7 +121,7 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
     tmp <- future_lapply(files, function(x) {
       p()
       tryCatch(
-        gsp(x),
+        gsp(x, ...),
         error = function(e) {
           warning(conditionMessage(e), call. = FALSE)
           return(NULL)
@@ -122,12 +133,15 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
   whichfailed <- which(vapply(tmp, is.null, logical(1)))
 
   if (length(whichfailed) == nb_files) {
-    warning("File import failed.\n",
-            "Check input files and function arguments.", call. = FALSE)
+    warning(
+      "File import failed.\n",
+      "Check input files and function arguments.",
+      call. = FALSE
+    )
     return(NULL)
   } else if (length(whichfailed) > 0) {
-
-    warning("Could not import one or more files:\n",
+    warning(
+      "Could not import one or more files:\n",
       paste(files[whichfailed], collapse = "\n"),
       call. = FALSE
     )
@@ -146,8 +160,11 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
     final <- cbind(range, tmp)
   } else {
     if (length(unique(lapply(tmp, function(x) x[, "wl"]))) != 1) {
-      stop("'interpolate = FALSE' can only work if all input files sample the ",
-           "same wavelengths.", call. = FALSE)
+      stop(
+        "'interpolate = FALSE' can only work if all input files sample the ",
+        "same wavelengths.",
+        call. = FALSE
+      )
     }
 
     # Errors have created NULL elements that we need to remove
