@@ -1,29 +1,32 @@
 test_that("get_metadata all", {
-
-  expect_message(
-    expect_snapshot_value(
-      lr_get_metadata(
-        test.file(),
-        ext = c("TRM", "ROH", "ttt", "trt", "jdx", "jaz", "JazIrrad")
-      ),
-      style = "json2"
+  expect_snapshot(
+    lr_get_metadata(
+      test.file(),
+      ext = c(
+        "TRM",
+        "ROH",
+        "ttt",
+        "trt",
+        "jdx",
+        "jaz",
+        "JazIrrad",
+        "spc"
+      )
     ),
-    "9 files"
+    cran = TRUE
   )
-
 })
 
 test_that("get_metadata recursive", {
-
   # Recursive
-  expect_message(
-    expect_snapshot_value(
-      lr_get_metadata(test.file(), ext = "ProcSpec", subdir = TRUE),
-      style = "json2"
+  expect_snapshot(
+    lr_get_metadata(
+      test.file(),
+      ext = c("ProcSpec", "spc", "RFL8", "TRM"),
+      subdir = TRUE
     ),
-    "5 files"
+    cran = TRUE
   )
-
 })
 
 test_that("get_metadata warn & error", {
@@ -50,5 +53,4 @@ test_that("get_metadata warn & error", {
     expect_null(lr_get_metadata(ext = "missing")),
     "No files found"
   )
-
 })
